@@ -3,12 +3,14 @@ package LWP::UserAgent::CHICaching;
 use 5.006000;
 
 our $AUTHORITY = 'cpan:KJETILK';
-our $VERSION   = '0.02';
+our $VERSION   = '0.04';
 
 use Moo;
 
 extends 'LWP::UserAgent';
-with 'LWP::UserAgent::Role::CHICaching', 'LWP::UserAgent::Role::CHICaching::SimpleKeyGen';
+with 'LWP::UserAgent::Role::CHICaching',
+     'LWP::UserAgent::Role::CHICaching::SimpleKeyGen',
+     'LWP::UserAgent::Role::CHICaching::SimpleMungeResponse';
 
 1;
 
@@ -67,7 +69,7 @@ Kjetil Kjernsmo E<lt>kjetilk@cpan.orgE<gt>.
 
 =head1 COPYRIGHT AND LICENCE
 
-This software is copyright (c) 2015 by Kjetil Kjernsmo.
+This software is copyright (c) 2015, 2016 by Kjetil Kjernsmo.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
