@@ -7,7 +7,7 @@ use Types::Standard qw(Str Bool Ref InstanceOf);
 use Types::URI -all;
 
 our $AUTHORITY = 'cpan:KJETILK';
-our $VERSION   = '0.03';
+our $VERSION   = '0.04';
 
 =pod
 
@@ -24,7 +24,9 @@ Compose it into a class, e.g.
   package LWP::UserAgent::MyCacher;
   use Moo;
   extends 'LWP::UserAgent';
-  with 'LWP::UserAgent::Role::CHICaching', 'LWP::UserAgent::Role::CHICaching::SimpleKeyGen';
+  with 'LWP::UserAgent::Role::CHICaching',
+       'LWP::UserAgent::Role::CHICaching::SimpleKeyGen',
+       'LWP::UserAgent::Role::CHICaching::SimpleMungeResponse';
 
 
 =head1 DESCRIPTION
@@ -75,8 +77,8 @@ C<Cache-Control> and C<Expires> headers) are used.
 =head2 Implemented elsewhere
 
 The following are required by this role, but implemented
-elsewhere. See L<LWP::UserAgent::Role::CHICaching::SimpleKeyGen> for
-further explanations.
+elsewhere. See L<LWP::UserAgent::Role::CHICaching::SimpleKeyGen> and
+L<LWP::UserAgent::Role::CHICaching::SimpleMungeResponse> for further explanations.
 
 =over
 
@@ -90,6 +92,15 @@ A method that returns true if the response may be cached even if it
 contains a C<Vary> header, false otherwise. The L<HTTP::Response>
 object will be passed to it as a parameter.
 
+=item C<< cache_set($response, $expires_in) >>
+
+A method that takes the L<HTTP::Response> from the client and an
+expires time in seconds and set the actual cache.
+
+=item C<< finalize($cached) >>
+
+A method that takes the cached entry as an argument, and will return a
+L<HTTP::Response> to return to the client.
 
 =back
 
@@ -104,6 +115,8 @@ has cache => (
 
 requires 'key';
 requires 'cache_vary';
+requires 'finalize';
+requires 'cache_set';
 
 has request_uri => (
 						  is =>'rw',
@@ -140,7 +153,7 @@ around request => sub {
 		######## The standard describing this is:
 		######## http://tools.ietf.org/html/rfc7234#section-4
 		$cached->header('Age' => $cached->current_age);
-		return $cached;
+		return $self->finalize($cached); # TODO: Deal with no-transform
 	} else {
 		my $res = $self->$orig(@args);
 
@@ -209,7 +222,7 @@ around request => sub {
 
 			}
 			if ($expires_in > 0) {
-				$self->cache->set($self->key, $res, { expires_in => $expires_in });
+				$self->cache_set($res, $expires_in);
 			}
 		}
 		return $res;
@@ -246,7 +259,7 @@ Thanks to Matt S. Trout for rewriting this to a Role.
 
 =head1 COPYRIGHT AND LICENCE
 
-This software is copyright (c) 2015 by Kjetil Kjernsmo.
+This software is copyright (c) 2015, 2016 by Kjetil Kjernsmo.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
